@@ -1,12 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #pragma once
 
-#include "filterinfogui.h"
+#include <MailImporter/FilterInfoGui>
 class MBoxImportWidget;
 
 class MBoxImporterInfoGui : public MailImporter::FilterInfoGui
